pub async fn launch_firefox(config: FoxBrowserConfig) -> Result<Page>Expand description
Launch Firefox with the given config and return a Page handle.
pub async fn launch_firefox(config: FoxBrowserConfig) -> Result<Page>Launch Firefox with the given config and return a Page handle.